==> haskell-ixset-typed-0.3.1.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ixset-typed
version: 0.3.1.1
id: ixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6
key: ixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6
license: BSD3
maintainer: Andres Löh <andres@well-typed.com>
synopsis: Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.
    .
    Sets can be created, modified, and queried in various ways.
    .
    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.
    .
    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.
category: Data Structures
author: Andres Löh, Happstack team, HAppS LLC
exposed: True
indefinite: False
exposed-modules:
    Data.IxSet.Typed Data.IxSet.Typed.Ix
abi: 3ad3f74bc1f3db226704caa42b934c2f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/ixset-typed-0.3.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/ixset-typed-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/ixset-typed-0.3.1.1
hs-libraries: HSixset-typed-0.3.1.1-4fUzEM1GbyD92fBmD83JC6
depends:
    base-4.10.0.0 containers-0.5.10.2 deepseq-1.4.3.0
    safecopy-0.9.3.3-8F3iHBCU2YoAi5AuuVN331
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o template-haskell-2.12.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             safecopy-0.9.3.3-8F3iHBCU2YoAi5AuuVN331=181585fc616e1f696d6f774a7c87f09f
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
haddock-interfaces: /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html: /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ixset-typed-0.3.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-ixset-typed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ixset-typed
version: 0.3.1
id: ixset-typed-0.3.1-BuMj3RYIQSdBrTyVycPfJG
key: ixset-typed-0.3.1-BuMj3RYIQSdBrTyVycPfJG
license: BSD3
maintainer: Andres Löh <andres@well-typed.com>
synopsis: Efficient relational queries on Haskell sets.
description:
    This Haskell package provides a data structure of sets that are indexed
    by potentially multiple indices.
    .
    Sets can be created, modified, and queried in various ways.
    .
    The package is a variant of the <https://hackage.haskell.org/package/ixset ixset>
    package. The ixset package makes use
    of run-time type information to find a suitable index on a query, resulting
    in possible run-time errors when no suitable index exists. In ixset-typed,
    the types of all indices available or tracked in the type system.
    Thus, ixset-typed should be safer to use than ixset, but in turn requires
    more GHC extensions.
    .
    At the moment, the two packages are relatively compatible. As a consequence
    of the more precise types, a few manual tweaks are necessary when switching
    from one to the other, but the interface is mostly the same.
category: Data Structures
author: Andres Löh, Happstack team, HAppS LLC
exposed: True
exposed-modules:
    Data.IxSet.Typed Data.IxSet.Typed.Ix
abi: 280203542e4794b140e827ab5c7904d9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/ixset-typed-0.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/ixset-typed-0.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/ixset-typed-0.3.1
hs-libraries: HSixset-typed-0.3.1-BuMj3RYIQSdBrTyVycPfJG
depends:
    base-4.9.0.0 containers-0.5.7.1 deepseq-1.4.2.0
    safecopy-0.9.3-KYLQ0FGhgnwJkR0AJUd9aI
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
haddock-interfaces: /usr/share/doc/haskell-ixset-typed/html/ixset-typed.haddock
haddock-html: /usr/share/doc/haskell-ixset-typed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
